---
feature_story: FS_44_36_84_88
feature_title: consume args one by one
feature_status: TEST
---

This feature trades performance for consistency:
*   instead of consuming as many user input args matching enums obtained in a previous query,
*   consume only one user input arg at a time and re-query before next consumption.

The feature is the opposite of these two:
*   FS_51_67_38_37: impossible arg combinations
*   FS_90_48_11_45: forced assignment from entire type value space

It is expected that number of queries per request will grow (increasing response time),
but the matching results are less confusing.

The feature determines behavior for cases like:
*   TD_76_09_29_31 mutually exclusive arg vals from diff arg types

See also:
*   FS_76_29_13_28: arg consumption priorities
